:doc:`/index`

.. _deepdiff_label:

DeepDiff
========

.. automodule:: deepdiff.diff

.. autoclass:: DeepDiff
    :members:

.. toctree::
   :maxdepth: 3

   basics
   view
   ignore_order
   ignore_types_or_values
   exclude_paths
   deep_distance
   numbers
   serialization
   optimizations
   stats
   troubleshoot

Back to :doc:`/index`
